
/* A few stubs to get liboiltmp1 to link correctly. */

void oil_param_get_source_data(void) {}
void oil_random_alpha(void) {}
void oil_random_argb(void) {}
void oil_test_get_source_data(void) {}
void oil_test_get_value(void) {}
void oil_test_get_arg_post_n(void) {}
void oil_test_get_arg_stride(void) {}

